==> jc-1.4.0.tar.gz: java/awt/RenderingHints__24KeyImpl.h <==
// final class java.awt.RenderingHints$KeyImpl

// class file dependencies
// @dep_class 77c41ec805713aab java_awt_RenderingHints__24Key
// @dep_class 358116fdf0b3eb6 java_awt_RenderingHints__24KeyImpl
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_RenderingHints__24Key

#include "java/awt/RenderingHints__24Key.h"

#ifndef _JC_java_awt_RenderingHints__24KeyImpl_H_
#define _JC_java_awt_RenderingHints__24KeyImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$sub_refs	_jc_java_awt_RenderingHints__24KeyImpl$sub_refs;
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$sub_nonrefs	_jc_java_awt_RenderingHints__24KeyImpl$sub_nonrefs;
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$refs	_jc_java_awt_RenderingHints__24KeyImpl$refs;
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$nonrefs	_jc_java_awt_RenderingHints__24KeyImpl$nonrefs;
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$object	_jc_java_awt_RenderingHints__24KeyImpl$object;

typedef const struct _jc_java_awt_RenderingHints__24KeyImpl$vmethods	_jc_java_awt_RenderingHints__24KeyImpl$vmethods;
typedef const struct _jc_java_awt_RenderingHints__24KeyImpl$vtable	_jc_java_awt_RenderingHints__24KeyImpl$vtable;
typedef const struct _jc_java_awt_RenderingHints__24KeyImpl$vtype	_jc_java_awt_RenderingHints__24KeyImpl$vtype;

// Constructors
extern void _jc_java_awt_RenderingHints__24KeyImpl$method$_init$05f1c43f83239c07(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *, jint, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_java_awt_RenderingHints__24KeyImpl$method$isCompatibleValue$9be6507832efe36e(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_RenderingHints__24KeyImpl$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_RenderingHints__24KeyImpl$method_info$isCompatibleValue$9be6507832efe36e;
extern _jc_method _jc_java_awt_RenderingHints__24KeyImpl$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_RenderingHints__24KeyImpl$vmethods {
	jboolean	(*isCompatibleValue$9be6507832efe36e)(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *);
};

// Vtable
struct _jc_java_awt_RenderingHints__24KeyImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_RenderingHints__24Key$vmethods	java_awt_RenderingHints__24Key;
	_jc_java_awt_RenderingHints__24KeyImpl$vmethods	java_awt_RenderingHints__24KeyImpl;
};

// Vtype
struct _jc_java_awt_RenderingHints__24KeyImpl$vtype {
	_jc_type			type;
	_jc_java_awt_RenderingHints__24KeyImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_RenderingHints__24KeyImpl$sub_refs {
	struct _jc_java_lang_String$object	*description;
	struct _jc_java_lang_Object$object	*v1;
	struct _jc_java_lang_Object$object	*v2;
	struct _jc_java_lang_Object$object	*v3;
};

// Reference instance fields (object)
struct _jc_java_awt_RenderingHints__24KeyImpl$refs {
    _jc_java_awt_RenderingHints__24KeyImpl$sub_refs	java_awt_RenderingHints__24KeyImpl;
    _jc_java_awt_RenderingHints__24Key$sub_refs	java_awt_RenderingHints__24Key;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_RenderingHints__24KeyImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_RenderingHints__24KeyImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_RenderingHints__24Key$sub_nonrefs	java_awt_RenderingHints__24Key;
    _jc_java_awt_RenderingHints__24KeyImpl$sub_nonrefs	java_awt_RenderingHints__24KeyImpl;
};

// Object instance structure
struct _jc_java_awt_RenderingHints__24KeyImpl$object {
	_jc_java_awt_RenderingHints__24KeyImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_RenderingHints__24KeyImpl$vtype	*vtype;
	_jc_java_awt_RenderingHints__24KeyImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_RenderingHints__24KeyImpl$vtype _jc_java_awt_RenderingHints__24KeyImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_RenderingHints__24KeyImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_RenderingHints__24KeyImpl$class_object;

#endif	/* _JC_java_awt_RenderingHints__24KeyImpl_H_ */

==> jc-1.4.6.tar.gz: java/awt/RenderingHints__24KeyImpl.h <==
// final class java.awt.RenderingHints$KeyImpl

// class file dependencies
// @dep_class 77c41ec805713aab java_awt_RenderingHints__24Key
// @dep_class 358116fdf0b3eb6 java_awt_RenderingHints__24KeyImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_RenderingHints__24Key

#include "java/awt/RenderingHints__24Key.h"

#ifndef _JC_java_awt_RenderingHints__24KeyImpl_H_
#define _JC_java_awt_RenderingHints__24KeyImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$sub_refs	_jc_java_awt_RenderingHints__24KeyImpl$sub_refs;
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$sub_nonrefs	_jc_java_awt_RenderingHints__24KeyImpl$sub_nonrefs;
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$refs	_jc_java_awt_RenderingHints__24KeyImpl$refs;
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$nonrefs	_jc_java_awt_RenderingHints__24KeyImpl$nonrefs;
typedef struct _jc_java_awt_RenderingHints__24KeyImpl$object	_jc_java_awt_RenderingHints__24KeyImpl$object;

typedef const struct _jc_java_awt_RenderingHints__24KeyImpl$vmethods	_jc_java_awt_RenderingHints__24KeyImpl$vmethods;
typedef const struct _jc_java_awt_RenderingHints__24KeyImpl$vtable	_jc_java_awt_RenderingHints__24KeyImpl$vtable;
typedef const struct _jc_java_awt_RenderingHints__24KeyImpl$vtype	_jc_java_awt_RenderingHints__24KeyImpl$vtype;

// Constructors
extern void _jc_java_awt_RenderingHints__24KeyImpl$method$_init$05f1c43f83239c07(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *, jint, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_RenderingHints__24KeyImpl$method$isCompatibleValue$9be6507832efe36e(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_RenderingHints__24KeyImpl$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_RenderingHints__24KeyImpl$method_info$isCompatibleValue$9be6507832efe36e;
extern _jc_method _jc_java_awt_RenderingHints__24KeyImpl$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_RenderingHints__24KeyImpl$vmethods {
	jboolean	(*isCompatibleValue$9be6507832efe36e)(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_RenderingHints__24KeyImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_RenderingHints__24KeyImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_RenderingHints__24Key$vmethods	java_awt_RenderingHints__24Key;
	_jc_java_awt_RenderingHints__24KeyImpl$vmethods	java_awt_RenderingHints__24KeyImpl;
};

// Vtype
struct _jc_java_awt_RenderingHints__24KeyImpl$vtype {
	_jc_type			type;
	_jc_java_awt_RenderingHints__24KeyImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_RenderingHints__24KeyImpl$sub_refs {
	struct _jc_java_lang_String$object	*description;
	struct _jc_java_lang_Object$object	*v1;
	struct _jc_java_lang_Object$object	*v2;
	struct _jc_java_lang_Object$object	*v3;
};

// Reference instance fields (object)
struct _jc_java_awt_RenderingHints__24KeyImpl$refs {
    _jc_java_awt_RenderingHints__24KeyImpl$sub_refs	java_awt_RenderingHints__24KeyImpl;
    _jc_java_awt_RenderingHints__24Key$sub_refs	java_awt_RenderingHints__24Key;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_RenderingHints__24KeyImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_RenderingHints__24KeyImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_RenderingHints__24Key$sub_nonrefs	java_awt_RenderingHints__24Key;
    _jc_java_awt_RenderingHints__24KeyImpl$sub_nonrefs	java_awt_RenderingHints__24KeyImpl;
};

// Object instance structure
struct _jc_java_awt_RenderingHints__24KeyImpl$object {
	_jc_java_awt_RenderingHints__24KeyImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_RenderingHints__24KeyImpl$vtype	*vtype;
	_jc_java_awt_RenderingHints__24KeyImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_RenderingHints__24KeyImpl$vtype _jc_java_awt_RenderingHints__24KeyImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_RenderingHints__24KeyImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_RenderingHints__24KeyImpl$class_object;

#endif	/* _JC_java_awt_RenderingHints__24KeyImpl_H_ */
